<?php

App::uses('CakeEventListener', 'Event');

class EvBasketCheckForDiscountListener implements CakeEventListener {

	public function implementedEvents() {
		return array(
			'EvDiscount.Component.DiscountCodes.codeAdded' => 'addDiscount'
		);
	}

	/**
	 * queue up the confirmation emails
	 *
	 * @param 	CakeEvent
	 */
	public function addDiscount(CakeEvent $Event) {
		// Event subject will be the EvDiscount.DiscountCodesComponent
		App::uses('DiscountLib', 'EvDiscount.Lib');

		$DiscountCode = EvClassRegistry::init('EvDiscount.DiscountCode');

		$EventSubject = $Event->subject();
		// try to read the cookies
		$codeCookie = $EventSubject->_controller->DiscountCookie->read('Code');

		if (! empty($codeCookie) && is_array($codeCookie)) {
			$validCodes = $DiscountCode->validateCodes($codeCookie);
		}

		$total = $EventSubject->_controller->BasketManager->findTotalRow(
			Configure::read('EvBasket.labels.subtotal')
		);

		$discount = 0;

		foreach ($validCodes as $codeData) {
			if (! empty($codeData['DiscountCode']['min_order']) && $total['amount'] < $codeData['DiscountCode']['min_order']) {
				continue;
			}

			$amount = DiscountLib::calculate($codeData, $total['amount']);
			if (! empty($amount)) {
				$discount += $amount;
			}
		}

		$EventSubject->_controller->BasketManager->manageTotalRow(
			Configure::read('EvBasket.labels.discount'),
			-$discount,
			15
		);

		$Event->subject()->_controller->BasketManager->rebuildTotals();

		return true;
	}
}
